@@ -10,6 +10,7 @@ from tracwikiimporter.importer import (
     TracWikiImporter,
     TracWikiImportController,
     )
+from tracwikiimporter.scripts.wiki_from_trac.extractors import WikiExporter
 
 
 class TestTracWikiImporter(TestCase):
@@ -48,20 +49,20 @@ class TestTracWikiImporter(TestCase):
                 'Wiki', mount_point='pages', mount_label='Pages',
                 import_id={
                         'source': 'Trac',
-                        'trac_url': 'http://example.com/trac/url/',
+                        'trac_url': 'http://example.com/trac/url',
                     },
             )
         ApiTicket.assert_called_once_with(
                 user_id=user._id,
                 capabilities={"import": ["Projects", "myproject"]},
                 expires=now + timedelta(minutes=60))
-        WikiExporter.assert_called_once_with('http://example.com/trac/url/',
+        WikiExporter.assert_called_once_with('http://example.com/trac/url',
                 Namespace.return_value)
         WikiExporter.return_value.export.assert_called_once_with(export_file)
         load_data.assert_called_once_with('/my/file',
                 WikiFromTrac.parser.return_value, Namespace.return_value)
         AuditLog.log.assert_called_once_with(
-                'import tool pages from http://example.com/trac/url/',
+                'import tool pages from http://example.com/trac/url',
                 project=project,
                 user=user,
                 url='foo',
@@ -128,3 +129,35 @@ class TestTracWikiImportController(TestController, TestCase):
                 status=302).follow()
         self.assertIn('Please wait and try again', r)
         self.assertEqual(import_tool.post.call_count, 0)
+
+
+class TestWikiExporter(TestCase):
+
+    def test_url_canonicalization(self):
+        test_urls = [
+            'https://sourceforge.net/apps/trac/shareaza',
+            'https://sourceforge.net/apps/trac/shareaza/',
+            'https://sourceforge.net/apps/trac/shareaza/wiki',
+            'https://sourceforge.net/apps/trac/shareaza/wiki/',
+            'https://sourceforge.net/apps/trac/shareaza/wiki/SomePage',
+        ]
+        for url in test_urls:
+            self.assertEqual(WikiExporter(url, None).base_url,
+                             'https://sourceforge.net/apps/trac/shareaza/')
+        self.assertEqual(WikiExporter('http://foo.com/wiki/bar/', None).base_url,
+                         'http://foo.com/wiki/bar/')
+
+    def test_page_list__special_chars(self):
+        class WikiExporterFunnyPages(WikiExporter):
+            def fetch(self, url):
+                return '''
+                    <div class="wikipage searchable">
+                        <ul>
+                            <li><a>Hello World</a></li>
+                            <li><a>Foo &amp; Bar</a></li>
+                        </ul>
+                    </div>
+                    '''
+
+        exp = WikiExporterFunnyPages('http://example.com/trac/', Mock())
+        self.assertEqual(exp.page_list(), {'Hello World', 'Foo & Bar'})
